@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package JSON::Schema::Tiny; # git description: v0.002-24-g2f7067b
+package JSON::Schema::Tiny; # git description: v0.003-10-g6eb5e0a
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate data against a schema, minimally
 # KEYWORDS: JSON Schema data validation structure specification tiny
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 use 5.016;  # for the unicode_strings feature
 no if "$]" >= 5.031009, feature => 'indirect';
@@ -22,6 +22,7 @@ use JSON::MaybeXS 1.004001 'is_bool';
 use Feature::Compat::Try;
 use JSON::PP ();
 use List::Util 1.33 'any';
+use Scalar::Util 'blessed';
 use namespace::clean;
 use Exporter 5.57 'import';
 
@@ -32,11 +33,24 @@ our $SHORT_CIRCUIT = 0;
 our $MAX_TRAVERSAL_DEPTH = 50;
 our $MOJO_BOOLEANS = 0;
 
-sub evaluate {
-  my ($data, $schema) = @_;
+sub new {
+  my ($class, %args) = @_;
+  bless(\%args, $class);
+}
 
+sub evaluate {
   croak 'evaluate called in void context' if not defined wantarray;
 
+  local $BOOLEAN_RESULT = $_[0]->{boolean_result} // $BOOLEAN_RESULT,
+  local $SHORT_CIRCUIT = $_[0]->{short_circuit} // $SHORT_CIRCUIT,
+  local $MAX_TRAVERSAL_DEPTH = $_[0]->{max_traversal_depth} // $MAX_TRAVERSAL_DEPTH,
+  local $MOJO_BOOLEANS = $_[0]->{mojo_booleans} // $MOJO_BOOLEANS,
+  shift
+    if blessed($_[0]) and blessed($_[0])->isa(__PACKAGE__);
+
+  die 'insufficient arguments' if @_ < 2;
+  my ($data, $schema) = @_;
+
   my $state = {
     depth => 0,
     data_path => '',
@@ -75,6 +89,8 @@ sub evaluate {
 ######## NO PUBLIC INTERFACES FOLLOW THIS POINT ########
 
 sub _eval {
+  croak '_eval called in void context' if not defined wantarray;
+  die 'insufficient arguments' if @_ < 3;
   my ($data, $schema, $state) = @_;
 
   # do not propagate upwards changes to depth, traversed paths,
@@ -122,6 +138,7 @@ sub _eval {
     my $sub = __PACKAGE__->can('_eval_keyword_'.($keyword =~ s/^\$//r));
     $valid = 0 if not $sub->($data, $schema, $state);
 
+    warn 'result is false but there are no errors' if not $valid and not @{$state->{errors}};
     last if not $valid and $state->{short_circuit};
   }
 
@@ -543,7 +560,7 @@ sub _eval_keyword_dependentSchemas {
     last if $state->{short_circuit};
   }
 
-  return E($state, 'not all subschemas are valid') if not $valid;
+  return E($state, 'not all dependencies are satisfied') if not $valid;
   return 1;
 }
 
@@ -992,19 +1009,25 @@ JSON::Schema::Tiny - Validate data against a schema, minimally
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
-  use JSON::Schema::Tiny qw(evaluate);
-
   my $data = { hello => 1 };
   my $schema = {
     type => "object",
     properties => { hello => { type => "integer" } },
   };
+
+  # functional interface:
+  use JSON::Schema::Tiny qw(evaluate);
   my $result = evaluate($data, $schema); # { valid => true }
 
+  # object-oriented interface:
+  use JSON::Schema::Tiny;
+  my $js = JSON::Schema::Tiny->new;
+  my $result = $js->evaluate($data, $schema); # { valid => true }
+
 =head1 DESCRIPTION
 
 This module aims to be a slimmed-down L<JSON Schema|https://json-schema.org/> evaluator and
@@ -1015,6 +1038,7 @@ specification. (See L</UNSUPPORTED JSON-SCHEMA FEATURES> below for exclusions.)
 
 =for Pod::Coverage is_type get_type is_equal is_elements_unique jsonp canonical_schema_uri E abort
 assert_keyword_type assert_pattern assert_non_negative_integer assert_array_schemas
+new
 
 =head2 evaluate
 
@@ -1063,7 +1087,8 @@ failure).
 =head1 OPTIONS
 
 All options are available as package-scoped global variables. Use L<local|perlfunc/local> to
-configure them for a local scope.
+configure them for a local scope. They may also be set via the constructor, as lower-cased values in
+a hash, e.g.: C<< JSON::Schema::Tiny->new(boolean_result => 1, max_traversal_depth => 10); >>
 
 =head2 C<$BOOLEAN_RESULT>
 
@@ -1204,6 +1229,12 @@ I am also usually active on irc, as 'ether' at C<irc.perl.org> and C<irc.freenod
 
 Karen Etheridge <ether@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Matt S Trout
+
+Matt S Trout <mst@shadowcat.co.uk>
+
 =head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2021 by Karen Etheridge.
